@@ -1,5 +1,5 @@
 /* Zcat - decompress and concatenate files to standard output
-   Copyright (C) 2010-2024 Antonio Diaz Diaz.
+   Copyright (C) 2010-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -110,6 +110,8 @@ void show_help()
                "  -V, --version                output version information and exit\n"
                "  -A, --show-all               equivalent to '-vET'\n"
                "  -b, --number-nonblank        number nonblank output lines\n"
+               "  -c, --stdout                 ignored, for gzip compatibility\n"
+               "  -d, --decompress             ignored, for gzip compatibility\n"
                "  -e                           equivalent to '-vE'\n"
                "  -E, --show-ends              display '$' at end of each line\n"
                "  -M, --format=<list>          process only the formats in <list>\n"
@@ -273,7 +275,7 @@ int main( const int argc, const char * const argv[] )
     { 'b', "number-nonblank",       Arg_parser::no  },	// cat
     { 'c', "stdout",                Arg_parser::no  },	// gzip
     { 'd', "decompress",            Arg_parser::no  },	// gzip
-    { 'e',  0,                      Arg_parser::no  },	// cat
+    { 'e', 0,                       Arg_parser::no  },	// cat
     { 'E', "show-ends",             Arg_parser::no  },	// cat
     { 'f', "force",                 Arg_parser::no  },	// gzip
     { 'h', "help",                  Arg_parser::no  },
@@ -287,7 +289,7 @@ int main( const int argc, const char * const argv[] )
     { 'r', "recursive",             Arg_parser::no  },
     { 'R', "dereference-recursive", Arg_parser::no  },
     { 's', "squeeze-blank",         Arg_parser::no  },	// cat
-    { 't',  0,                      Arg_parser::no  },	// cat
+    { 't', 0,                       Arg_parser::no  },	// cat
     { 'T', "show-tabs",             Arg_parser::no  },	// cat
     { 'v', "show-nonprinting",      Arg_parser::no  },	// cat
     { 'V', "version",               Arg_parser::no  },
@@ -297,7 +299,7 @@ int main( const int argc, const char * const argv[] )
     { lz_opt,  "lz",                Arg_parser::yes },
     { xz_opt,  "xz",                Arg_parser::yes },
     { zst_opt, "zst",               Arg_parser::yes },
-    {  0,   0,                      Arg_parser::no  } };
+    { 0, 0,                         Arg_parser::no  } };
 
   const Arg_parser parser( argc, argv, options );
   if( parser.error().size() )				// bad option
@@ -318,14 +320,14 @@ int main( const int argc, const char * const argv[] )
                 cat_options.show_nonprinting = true;
                 cat_options.show_tabs = true; break;
       case 'b': cat_options.number_lines = 1; break;
-      case 'c': break;
-      case 'd': break;
+      case 'c': break;					// ignored
+      case 'd': break;					// ignored
       case 'e': cat_options.show_nonprinting = true;	// fall through
       case 'E': cat_options.show_ends = true; break;
       case 'f': break;
       case 'h': show_help(); return 0;
-      case 'l': break;
-      case 'L': break;
+      case 'l': break;					// ignored
+      case 'L': break;					// ignored
       case 'M': parse_format_list( arg, pn ); break;
       case 'n': if( cat_options.number_lines == 0 )
                   { cat_options.number_lines = 2; } break;
