@@ -1,5 +1,5 @@
 /* Zcmp - decompress and compare two files byte by byte
-   Copyright (C) 2010-2024 Antonio Diaz Diaz.
+   Copyright (C) 2010-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -105,7 +105,7 @@ const char * format_num3( long long num )
   char * p = buf + bufsize - 1;		// fill the buffer backwards
   *p = 0;	// terminator
   const bool negative = num < 0;
-  if( num > 1024 || num < -1024 )
+  if( num > 9999 || num < -9999 )
     {
     char prefix = 0;			// try binary first, then si
     for( int i = 0; i < n && num != 0 && num % 1024 == 0; ++i )
@@ -405,7 +405,7 @@ int main( const int argc, const char * const argv[] )
     { lz_opt,  "lz",         Arg_parser::yes },
     { xz_opt,  "xz",         Arg_parser::yes },
     { zst_opt, "zst",        Arg_parser::yes },
-    {  0,   0,               Arg_parser::no  } };
+    { 0, 0,                  Arg_parser::no  } };
 
   const Arg_parser parser( argc, argv, options );
   if( parser.error().size() )				// bad option
@@ -430,7 +430,7 @@ int main( const int argc, const char * const argv[] )
       case 'l': list = true; break;
       case 'M': parse_format_list( sarg, pn ); break;
       case 'n': max_size = getnum( arg, pn ); break;
-      case 'N': break;
+      case 'N': break;					// already processed
       case 'O': parse_format_types2( sarg, pn, format_types ); break;
       case 'q': verbosity = -1; break;
       case 's': scripted = true; break;
