@@ -1,5 +1,5 @@
 /* Zgrep - search compressed files for a regular expression
-   Copyright (C) 2010-2024 Antonio Diaz Diaz.
+   Copyright (C) 2010-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -244,7 +244,7 @@ int main( const int argc, const char * const argv[] )
     { 'h', "no-filename",           Arg_parser::no  },	// grep GNU
     { 'H', "with-filename",         Arg_parser::no  },	// grep GNU
     { 'i', "ignore-case",           Arg_parser::no  },	// grep
-    { 'I',  0,                      Arg_parser::no  },	// grep GNU
+    { 'I', 0,                       Arg_parser::no  },	// grep GNU
     { 'l', "files-with-matches",    Arg_parser::no  },	// grep
     { 'L', "files-without-match",   Arg_parser::no  },	// grep GNU
     { 'm', "max-count",             Arg_parser::yes },	// grep GNU
@@ -276,7 +276,7 @@ int main( const int argc, const char * const argv[] )
     { lz_opt,  "lz",                Arg_parser::yes },
     { xz_opt,  "xz",                Arg_parser::yes },
     { zst_opt, "zst",               Arg_parser::yes },
-    {  0,   0,                      Arg_parser::no  } };
+    { 0, 0,                         Arg_parser::no  } };
 
   const Arg_parser parser( argc, argv, options );
   if( parser.error().size() )				// bad option
@@ -381,8 +381,8 @@ int main( const int argc, const char * const argv[] )
   int retval = 1;
   bool error = false;
   bool stdin_used = false;
-  while( next_filename( filenames, input_filename, error, recursive,
-                        false, no_messages ) )
+  while( next_filename( filenames, input_filename, error, recursive, false,
+                        no_messages ) )
     {
     int infd;
     if( input_filename == "." )
